==> amity-sdk-7.8.1-sources.jar: main/com/ekoapp/ekosdk/internal/data/dao/AmityUserFeedPagingDao.kt <==
package com.ekoapp.ekosdk.internal.data.dao

import androidx.paging.PagingSource
import androidx.room.Dao
import androidx.room.RawQuery
import androidx.sqlite.db.SimpleSQLiteQuery
import co.amity.rxremotemediator.AmityPagingDao
import co.amity.rxremotemediator.AmityPagingId
import com.amity.socialcloud.sdk.api.social.post.query.AmityUserFeedSortOption
import com.amity.socialcloud.sdk.model.social.post.AmityPost
import com.amity.socialcloud.sdk.social.data.post.paging.UserFeedKeyCreator
import com.ekoapp.ekosdk.internal.PostEntity
import com.ekoapp.ekosdk.internal.data.AmityNonce
import com.amity.socialcloud.sdk.social.data.post.paging.UserPostKeyCreator
import com.ekoapp.ekosdk.internal.paging.DynamicQueryStreamPagingDao

@Dao
internal interface AmityUserFeedPagingDao : DynamicQueryStreamPagingDao<PostEntity> {

    @RawQuery(observedEntities = [PostEntity::class, AmityPagingId::class])
    override fun queryPagingData(sqlQuery: SimpleSQLiteQuery): PagingSource<Int, PostEntity>

    fun getUserFeedPagingSource(
        userId: String,
        sortOption: AmityUserFeedSortOption,
        isDeleted: Boolean?,
        feedSources: List<String>,
        matchingOnlyParentPosts: Boolean,
        postTypes: List<AmityPost.DataType>,
    ): PagingSource<Int, PostEntity> {
        val order = if (AmityUserFeedSortOption.LAST_CREATED == sortOption)
            AmityPagingDao.Order.DESC else AmityPagingDao.Order.ASC
        return queryPagingData(
            generateQueryStreamSQL(
                tableName = "post",
                primaryKeyColumnName = "postId",
                additionalPrimaryKeys = emptyMap(),
                dynamicQueryStreamKeyCreator = UserFeedKeyCreator(
                    userId = userId,
                    sortBy = sortOption.apiKey,
                    isDeleted = isDeleted,
                    postTypes = postTypes,
                    matchingOnlyParentPosts = matchingOnlyParentPosts,
                    feedSources = feedSources
                ),
                nonce = AmityNonce.USER_FEED_V5,
                order = order,
                sortColumn = "createdAt",
            )
        )
    }
}

==> amity-sdk-7.12.1-sources.jar: main/com/ekoapp/ekosdk/internal/data/dao/AmityUserFeedPagingDao.kt <==
package com.ekoapp.ekosdk.internal.data.dao

import androidx.paging.PagingSource
import androidx.room.Dao
import androidx.room.RawQuery
import androidx.sqlite.db.SimpleSQLiteQuery
import co.amity.rxremotemediator.AmityPagingDao
import co.amity.rxremotemediator.AmityPagingId
import com.amity.socialcloud.sdk.api.social.post.query.AmityUserFeedSortOption
import com.amity.socialcloud.sdk.model.social.post.AmityPost
import com.amity.socialcloud.sdk.social.data.post.paging.UserFeedKeyCreator
import com.ekoapp.ekosdk.internal.PostEntity
import com.ekoapp.ekosdk.internal.data.AmityNonce
import com.amity.socialcloud.sdk.social.data.post.paging.UserPostKeyCreator
import com.ekoapp.ekosdk.internal.paging.DynamicQueryStreamPagingDao

@Dao
internal interface AmityUserFeedPagingDao : DynamicQueryStreamPagingDao<PostEntity> {

    @RawQuery(observedEntities = [PostEntity::class, AmityPagingId::class])
    override fun queryPagingData(sqlQuery: SimpleSQLiteQuery): PagingSource<Int, PostEntity>

    fun getUserFeedPagingSource(
        userId: String,
        sortOption: AmityUserFeedSortOption,
        isDeleted: Boolean?,
        feedSources: List<String>,
        matchingOnlyParentPosts: Boolean,
        postTypes: List<AmityPost.DataType>,
        includeMixedStructure: Boolean,
    ): PagingSource<Int, PostEntity> {
        val order = if (AmityUserFeedSortOption.LAST_CREATED == sortOption)
            AmityPagingDao.Order.DESC else AmityPagingDao.Order.ASC
        return queryPagingData(
            generateQueryStreamSQL(
                tableName = "post",
                primaryKeyColumnName = "postId",
                additionalPrimaryKeys = emptyMap(),
                dynamicQueryStreamKeyCreator = UserFeedKeyCreator(
                    userId = userId,
                    sortBy = sortOption.apiKey,
                    isDeleted = isDeleted,
                    postTypes = postTypes,
                    matchingOnlyParentPosts = matchingOnlyParentPosts,
                    feedSources = feedSources,
                    includeMixedStructure = includeMixedStructure
                ),
                nonce = AmityNonce.USER_FEED_V5,
                order = order,
                sortColumn = "createdAt",
            )
        )
    }
}
